@@ -4,9 +4,9 @@ from django.db import models
 
 from pulpcore.plugin.models import (
     Content,
+    Distribution,
     FilesystemExporter,
     Publication,
-    PublicationDistribution,
     Remote,
     Repository,
 )
@@ -60,9 +60,37 @@ class FileRepository(Repository):
     CONTENT_TYPES = [FileContent]
     REMOTE_TYPES = [FileRemote]
 
+    manifest = models.TextField(default="PULP_MANIFEST")
+    autopublish = models.BooleanField(default=False)
+
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
+    def on_new_version(self, version):
+        """
+        Called when new repository versions are created.
+
+        Args:
+            version: The new repository version.
+        """
+        super().on_new_version(version)
+
+        # avoid circular import issues
+        from pulp_file.app import tasks
+
+        if self.autopublish:
+            publication = tasks.publish(
+                manifest=self.manifest,
+                repository_version_pk=version.pk,
+            )
+
+            distributions = self.distributions.all()
+
+            if publication and distributions:
+                for distribution in distributions:
+                    distribution.publication = publication
+                    distribution.save()
+
     def finalize_new_version(self, new_version):
         """
         Finalize and validate the new repository version.
@@ -98,7 +126,7 @@ class FilePublication(Publication):
         validate_publication_paths(self)
 
 
-class FileDistribution(PublicationDistribution):
+class FileDistribution(Distribution):
     """
     Distribution for 'file' content.
     """
