@@ -6,8 +6,8 @@ from pulpcore.plugin import models
 from pulpcore.plugin.serializers import (
     ContentChecksumSerializer,
     DetailRelatedField,
+    DistributionSerializer,
     FilesystemExporterSerializer,
-    PublicationDistributionSerializer,
     PublicationSerializer,
     RemoteSerializer,
     RepositorySerializer,
@@ -62,8 +62,23 @@ class FileRepositorySerializer(RepositorySerializer):
     Serializer for File Repositories.
     """
 
+    autopublish = serializers.BooleanField(
+        help_text=_(
+            "Whether to automatically create publications for new repository versions, "
+            "and update any distributions pointing to this repository."
+        ),
+        default=False,
+        required=False,
+    )
+
+    manifest = serializers.CharField(
+        help_text=_("Filename to use for manifest file containing metadata for all the files."),
+        default="PULP_MANIFEST",
+        required=False,
+    )
+
     class Meta:
-        fields = RepositorySerializer.Meta.fields
+        fields = RepositorySerializer.Meta.fields + ("autopublish", "manifest")
         model = FileRepository
 
 
@@ -91,7 +106,7 @@ class FilePublicationSerializer(PublicationSerializer):
 
     distributions = DetailRelatedField(
         help_text=_("This publication is currently hosted as defined by these distributions."),
-        source="file_filedistribution",
+        source="distribution_set",
         view_name="filedistributions-detail",
         many=True,
         read_only=True,
@@ -99,6 +114,7 @@ class FilePublicationSerializer(PublicationSerializer):
     manifest = serializers.CharField(
         help_text=_("Filename to use for manifest file containing metadata for all the files."),
         default="PULP_MANIFEST",
+        required=False,
     )
 
     class Meta:
@@ -106,13 +122,21 @@ class FilePublicationSerializer(PublicationSerializer):
         fields = PublicationSerializer.Meta.fields + ("distributions", "manifest")
 
 
-class FileDistributionSerializer(PublicationDistributionSerializer):
+class FileDistributionSerializer(DistributionSerializer):
     """
     Serializer for File Distributions.
     """
 
+    publication = DetailRelatedField(
+        required=False,
+        help_text=_("Publication to be served"),
+        view_name_pattern=r"publications(-.*/.*)?-detail",
+        queryset=models.Publication.objects.exclude(complete=False),
+        allow_null=True,
+    )
+
     class Meta:
-        fields = PublicationDistributionSerializer.Meta.fields
+        fields = DistributionSerializer.Meta.fields + ("publication",)
         model = FileDistribution
 
 
