@@ -9,10 +9,10 @@ from pulpcore.plugin.serializers import (
     PublicationExportSerializer,
     RepositorySyncURLSerializer,
 )
-from pulpcore.plugin.tasking import enqueue_with_reservation, fs_publication_export
+from pulpcore.plugin.tasking import dispatch, fs_publication_export
 from pulpcore.plugin.viewsets import (
-    BaseDistributionViewSet,
     ContentFilter,
+    DistributionViewSet,
     ExporterViewSet,
     ExportViewSet,
     OperationPostponedResponse,
@@ -98,10 +98,14 @@ class FileRepositoryViewSet(RepositoryViewSet, ModifyRepositoryActionMixin):
         remote = serializer.validated_data.get("remote", repository.remote)
 
         mirror = serializer.validated_data.get("mirror", False)
-        result = enqueue_with_reservation(
+        result = dispatch(
             tasks.synchronize,
             [repository, remote],
-            kwargs={"remote_pk": remote.pk, "repository_pk": repository.pk, "mirror": mirror},
+            kwargs={
+                "remote_pk": str(remote.pk),
+                "repository_pk": str(repository.pk),
+                "mirror": mirror,
+            },
         )
         return OperationPostponedResponse(result, request)
 
@@ -158,7 +162,7 @@ class FilePublicationViewSet(PublicationViewSet):
         repository_version = serializer.validated_data.get("repository_version")
         manifest = serializer.validated_data.get("manifest")
 
-        result = enqueue_with_reservation(
+        result = dispatch(
             tasks.publish,
             [repository_version.repository],
             kwargs={"repository_version_pk": str(repository_version.pk), "manifest": str(manifest)},
@@ -166,7 +170,7 @@ class FilePublicationViewSet(PublicationViewSet):
         return OperationPostponedResponse(result, request)
 
 
-class FileDistributionViewSet(BaseDistributionViewSet):
+class FileDistributionViewSet(DistributionViewSet):
     """
     <!-- User-facing documentation, rendered as html-->
     FileDistributions host <a href="#operation/publications_file_file_list">File
@@ -221,9 +225,9 @@ class FileFilesystemExportViewSet(ExportViewSet):
         serializer = PublicationExportSerializer(data=request.data, context={"request": request})
         serializer.is_valid(raise_exception=True)
         publication = serializer.validated_data.get("publication")
-        result = enqueue_with_reservation(
+        result = dispatch(
             fs_publication_export,
             [publication, exporter],
-            kwargs={"exporter_pk": exporter.pk, "publication_pk": publication.pk},
+            kwargs={"exporter_pk": str(exporter.pk), "publication_pk": str(publication.pk)},
         )
         return OperationPostponedResponse(result, request)
