@@ -40,7 +40,7 @@ configuration = cfg.get_bindings_config()
 def set_up_module():
     """Skip tests Pulp 3 isn't under test or if pulp-file isn't installed."""
     require_pulp_3(SkipTest)
-    require_pulp_plugins({"pulp_file"}, SkipTest)
+    require_pulp_plugins({"file"}, SkipTest)
 
 
 def gen_file_client():
